@@ -1981,14 +1981,14 @@ void socket_layer::set_event_handler(event_handler* handler, fz::socket_event_fl
 void socket_layer::forward_socket_event(socket_event_source* source, socket_event_flag t, int error)
 {
 	if (event_handler_) {
-		(*event_handler_)(socket_event(source, t, error));
+		event_handler_->send_event<socket_event>(source, t, error);
 	}
 }
 
 void socket_layer::forward_hostaddress_event(socket_event_source* source, std::string const& address)
 {
 	if (event_handler_) {
-		(*event_handler_)(hostaddress_event(source, address));
+		event_handler_->send_event<hostaddress_event>(source, address);
 	}
 }
 
